@@ -1,6 +1,6 @@
 package Text::ANSI::Printf;
 
-our $VERSION = "2.03";
+our $VERSION = "2.04";
 
 use v5.14;
 use warnings;
@@ -50,7 +50,7 @@ Text::ANSI::Printf - printf function for string with ANSI sequence
 
 =head1 VERSION
 
-Version 2.03
+Version 2.04
 
 =head1 SYNOPSIS
 
@@ -72,7 +72,7 @@ capability of handling:
     - Backspaces
 
 You can give any string including these data as an argument for
-C<printf> and C<sprintf> funcitons.  Each field width is calculated
+C<printf> and C<sprintf> functions.  Each field width is calculated
 based on its visible appearance.
 
 For example,
@@ -88,7 +88,7 @@ However, if the arguments are colored by ANSI sequence,
     printf("| %-5s | %-5s | %-5s |\n",
            "\e[31mRed\e[m", "\e[32mGreen\e[m", "\e[34mBlue\e[m");
 
-this code produces undsirable result:
+this code produces undesirable result:
 
     | Red | Green | Blue |
 
@@ -110,13 +110,17 @@ The original C<printf> function has the ability to specify the
 arguments to be targeted by the position specifier, but by default
 this module assumes that the arguments will appear in the given order,
 so you will not get the expected result. If you wish to use it, set
-the variable C<$REORDER> to 1.
+the package variable C<$REORDER> to 1.
 
-    $Text::ANSI::Printf::REORDER = 1;.
+    $Text::ANSI::Printf::REORDER = 1;
 
 By doing so, the order in which arguments appear can be changed and
 the same argument can be processed even if it appears more than once.
 
+If you want to enable this feature only in specific cases, create a
+wrapper function and declare C<$Text::ANSI::Printf::REORDER> as local
+in it.
+
 This behavior is experimental and may change in the future.
 
 =head1 FUNCTIONS
@@ -131,7 +135,7 @@ This behavior is experimental and may change in the future.
 
 =item ansi_sprintf FORMAT, LIST
 
-Use just like perl's I<printf> and I<sprintf> functions
+Use just like Perl's I<printf> and I<sprintf> functions
 except that I<printf> does not take FILEHANDLE.
 
 =back
